@@ -1,11 +1,12 @@
+# -*- coding: utf-8 -*-
 import logging
 from datetime import datetime
 
 from django.core.management.base import BaseCommand
-from django.conf import settings
 
 from feedzilla.util.parse import parse_feed
 from feedzilla.models import Feed, Post
+from feedzilla import settings
 
 class Command(BaseCommand):
     help = u'Update feeds'
@@ -17,7 +18,7 @@ class Command(BaseCommand):
             logging.debug('parsing %s' % feed.feed_url)
 
             resp = parse_feed(feed.feed_url, etag=feed.etag,
-                              summary_size=settings.FEEDZILLA_SUMMARY_SIZE)
+                              summary_size=settings.SUMMARY_SIZE)
             if not resp['success']:
                 logging.debug('Failure')
             else:
