@@ -11,7 +11,7 @@ urlpatterns = patterns('feedzilla.views',
     url('^tag/(?P<tag_value>.+)/$', 'tag', name='feedzilla_tag'),
     url('^sources/$', 'sources', name='feedzilla_sources'),
     url('^search/$', 'search', name='feedzilla_search'),
-    url('^addblog/$', 'add_blog', name='feedzilla_add_blog'),
+    url('^submit/$', 'submit_blog', name='feedzilla_submit_blog'),
 )
 
 urlpatterns += patterns('django.contrib.syndication.views',
